@@ -8,8 +8,6 @@ messages with ones that:
 This is largely built by fussing around in argparse implementation details, and is by
 far the hackiest part of `dcargs`.
 """
-
-
 import argparse
 import contextlib
 import dataclasses
@@ -26,7 +24,7 @@ from rich.table import Table
 from rich.text import Text
 from rich.theme import Theme
 
-from . import _strings
+from . import _arguments, _strings
 
 
 @dataclasses.dataclass
@@ -124,6 +122,8 @@ def ansi_context() -> ContextManager[None]:
 def str_from_rich(
     renderable: RenderableType, width: Optional[int] = None, soft_wrap: bool = False
 ) -> str:
+    # TODO: everywhere that this function is used is a little bit sketchy. Could use
+    # re-thinking.
     console = Console(width=width, theme=THEME.as_rich_theme())
     with console.capture() as out:
         console.print(renderable, soft_wrap=soft_wrap)
@@ -136,6 +136,10 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
         width = shutil.get_terminal_size().columns - 2
         max_help_position = 24
         self._fixed_help_position = False
+
+        # TODO: hacky. Refactor this.
+        self._strip_ansi_sequences = not _arguments.USE_RICH
+
         super().__init__(prog, indent_increment, max_help_position, width)
 
     def _format_args(self, action, default_metavar):
@@ -146,12 +150,18 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
         out = get_metavar(1)[0]
         if isinstance(out, str):
             # Can result in an failed argparse assertion if we turn off soft wrapping.
-            return str_from_rich(
-                Text(
-                    out,
-                    style=THEME.metavar_fixed if out == "{fixed}" else THEME.metavar,
-                ),
-                soft_wrap=True,
+            return (
+                out
+                if self._strip_ansi_sequences
+                else str_from_rich(
+                    Text.from_ansi(
+                        out,
+                        style=THEME.metavar_fixed
+                        if out == "{fixed}"
+                        else THEME.metavar,
+                    ),
+                    soft_wrap=True,
+                )
             )
         return out
 
@@ -192,7 +202,12 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
         self._fixed_help_position = True
         help2 = super().format_help()
 
-        return help1 if help1.count("\n") < help2.count("\n") else help2
+        out = help1 if help1.count("\n") < help2.count("\n") else help2
+
+        if self._strip_ansi_sequences:
+            return _strings.strip_ansi_sequences(out)
+        else:
+            return out
 
     class _Section(object):
         def __init__(self, formatter, parent, heading=None):
@@ -280,12 +295,13 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
 
         def _format_action(self, action: argparse.Action):
             invocation = self.formatter._format_action_invocation(action)
+            indent = self.formatter._current_indent
             help_position = min(
-                self.formatter._action_max_length + 4, self.formatter._max_help_position
+                self.formatter._action_max_length + 4 + indent,
+                self.formatter._max_help_position,
             )
             if self.formatter._fixed_help_position:
                 help_position = 4
-            indent = self.formatter._current_indent
 
             item_parts: List[RenderableType] = []
 
@@ -295,7 +311,9 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
                 # with the helptext strings defined via docstrings and set by
                 # _arguments.py.
                 assert action.help is not None
-                action.help = "[helptext]" + action.help + "[/helptext]"
+                action.help = str_from_rich(
+                    Text.from_markup("[helptext]" + action.help + "[/helptext]")
+                )
             if (
                 action.help
                 and len(_strings.strip_ansi_sequences(invocation)) < help_position - 1
@@ -310,7 +328,7 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
                         style=THEME.invocation,
                     ),
                     # Unescape % signs, which need special handling in argparse.
-                    Text.from_markup(action.help.replace("%%", "%")),
+                    Text.from_ansi(action.help.replace("%%", "%")),
                 )
                 item_parts.append(table)
 
@@ -326,7 +344,7 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
                     item_parts.append(
                         Padding(
                             # Unescape % signs, which need special handling in argparse.
-                            Text.from_markup(action.help.replace("%%", "%")),
+                            Text.from_ansi(action.help.replace("%%", "%")),
                             pad=(0, 0, 0, help_position),
                         )
                     )
@@ -409,7 +427,7 @@ class DcargsArgparseHelpFormatter(argparse.RawDescriptionHelpFormatter):
                 # Note: we don't use rich.rule.Rule() because this will make all of
                 # the panels expand to fill the full width of the console. (this only
                 # impacts single-column layouts)
-                self.formatter._dcargs_rule = Text(
+                self.formatter._dcargs_rule = Text.from_ansi(
                     "─" * max_width, style=THEME.border, overflow="crop"
                 )
             elif len(self.formatter._dcargs_rule._text[0]) < max_width:
