@@ -22,8 +22,9 @@ from typing import (
 )
 
 import rich.markup
+from rich.text import Text
 
-from . import _fields, _instantiators, _resolver
+from . import _argparse_formatter, _fields, _instantiators, _resolver
 from . import _shtab as shtab
 from . import _strings
 from .conf import _markers
@@ -36,25 +37,12 @@ except ImportError:
     from backports.cached_property import cached_property  # type: ignore
 
 
-class _PatchedList(list):
-    """Custom tuple type, for avoiding "default not in choices" errors when the default
-    is set to MISSING_NONPROP.
-
-    This solves a choices error raised by argparse in a very specific edge case:
-    literals in containers as positional arguments."""
-
-    def __init__(self, li):
-        super(_PatchedList, self).__init__(li)
-
-    def __contains__(self, x: Any) -> bool:
-        return list.__contains__(self, x) or x is _fields.MISSING_NONPROP
-
-
 @dataclasses.dataclass(frozen=True)
 class ArgumentDefinition:
     """Structure containing everything needed to define an argument."""
 
     prefix: str  # Prefix for nesting.
+    subcommand_prefix: str  # Prefix for nesting.
     field: _fields.FieldDefinition
     type_from_typevar: Dict[TypeVar, Type]
 
@@ -77,10 +65,7 @@ class ArgumentDefinition:
         # the field default to a string format, then back to the desired type.
         kwargs["default"] = _fields.MISSING_NONPROP
 
-        if "choices" in kwargs:
-            kwargs["choices"] = _PatchedList(kwargs["choices"])
-
-        # Note that the name must be passed in as a position argument.
+        # Add argument! Note that the name must be passed in as a position argument.
         arg = parser.add_argument(name_or_flag, **kwargs)
 
         # Do our best to tab complete paths.
@@ -119,8 +104,9 @@ class ArgumentDefinition:
             _rule_recursive_instantiator_from_type,
             _rule_convert_defaults_to_strings,
             _rule_generate_helptext,
-            _rule_set_name_or_flag,
+            _rule_set_name_or_flag_and_dest,
             _rule_positional_special_handling,
+            _rule_static_cast_choices_to_patched_list,
         )
         return functools.reduce(
             lambda lowered, rule: rule(self, lowered),
@@ -185,7 +171,7 @@ def _rule_handle_boolean_flags(
     if (
         arg.field.default in _fields.MISSING_SINGLETONS
         or arg.field.is_positional()
-        or _markers.FLAG_CONVERSION_OFF in arg.field.markers
+        or _markers.FlagConversionOff in arg.field.markers
     ):
         # Treat bools as a normal parameter.
         return lowered
@@ -222,7 +208,7 @@ def _rule_recursive_instantiator_from_type(
     Conversions from strings to our desired types happen in the instantiator; this is a
     bit more flexible, and lets us handle more complex types like enums and multi-type
     tuples."""
-    if _markers.FIXED in arg.field.markers:
+    if _markers.Fixed in arg.field.markers:
         return dataclasses.replace(
             lowered,
             instantiator=None,
@@ -294,12 +280,18 @@ def _rule_convert_defaults_to_strings(
 
 # This can be turned off when we don't want rich-based formatting. (notably for
 # completion scripts)
+#
+# TODO: the global state here is gross. Should be revisited.
 USE_RICH = True
 
 
 def _rich_tag_if_enabled(x: str, tag: str):
     x = rich.markup.escape(x)
-    return x if not USE_RICH else f"[{tag}]{x}[/{tag}]"
+    return (
+        x
+        if not USE_RICH
+        else _argparse_formatter.str_from_rich(Text.from_markup(f"[{tag}]{x}[/{tag}]"))
+    )
 
 
 def _rule_generate_helptext(
@@ -309,7 +301,9 @@ def _rule_generate_helptext(
     """Generate helptext from docstring, argument name, default values."""
 
     # If the suppress marker is attached, hide the argument.
-    if _markers.SUPPRESS in arg.field.markers:
+    if _markers.Suppress in arg.field.markers or (
+        _markers.SuppressFixed in arg.field.markers and lowered.is_fixed()
+    ):
         return dataclasses.replace(lowered, help=argparse.SUPPRESS)
 
     help_parts = []
@@ -362,19 +356,30 @@ def _rule_generate_helptext(
     return dataclasses.replace(lowered, help=" ".join(help_parts))
 
 
-def _rule_set_name_or_flag(
+def _rule_set_name_or_flag_and_dest(
     arg: ArgumentDefinition,
     lowered: LoweredArgumentDefinition,
 ) -> LoweredArgumentDefinition:
+    # Positional arguments: no -- prefix.
     if arg.field.is_positional():
         name_or_flag = _strings.make_field_name([arg.prefix, arg.field.name])
+    # Negated booleans.
     elif lowered.action == "store_false":
         name_or_flag = "--" + _strings.make_field_name(
             [arg.prefix, "no-" + arg.field.name]
         )
+    # Prefix keyword arguments with --.
     else:
         name_or_flag = "--" + _strings.make_field_name([arg.prefix, arg.field.name])
 
+    # Strip.
+    if name_or_flag.startswith("--") and arg.subcommand_prefix != "":
+        # This will run even when unused because we want the assert.
+        strip_prefix = "--" + arg.subcommand_prefix + "."
+        assert name_or_flag.startswith(strip_prefix)
+        if _markers.OmitSubcommandPrefixes in arg.field.markers:
+            name_or_flag = "--" + name_or_flag[len(strip_prefix) :]
+
     return dataclasses.replace(
         lowered,
         name_or_flag=name_or_flag,
@@ -410,3 +415,27 @@ def _rule_positional_special_handling(
         metavar=metavar,
         nargs=nargs,
     )
+
+
+class _PatchedList(list):
+    """Custom list type, for avoiding "default not in choices" errors when the default
+    is set to MISSING_NONPROP.
+
+    This solves a choices error raised by argparse in a very specific edge case:
+    literals in containers as positional arguments."""
+
+    def __init__(self, li):
+        super(_PatchedList, self).__init__(li)
+
+    def __contains__(self, x: Any) -> bool:
+        return list.__contains__(self, x) or x is _fields.MISSING_NONPROP
+
+
+def _rule_static_cast_choices_to_patched_list(
+    arg: ArgumentDefinition,
+    lowered: LoweredArgumentDefinition,
+) -> LoweredArgumentDefinition:
+    return dataclasses.replace(
+        lowered,
+        choices=_PatchedList(lowered.choices) if lowered.choices is not None else None,
+    )
