@@ -1,4 +1,5 @@
 """Interface for generating `argparse.ArgumentParser()` definitions from callables."""
+
 from __future__ import annotations
 
 import argparse
@@ -6,7 +7,8 @@ import dataclasses
 import itertools
 from typing import Any, Callable, Dict, List, Optional, Set, Type, TypeVar, Union, cast
 
-from typing_extensions import get_args, get_origin
+import rich.markup
+from typing_extensions import Annotated, get_args, get_origin
 
 from . import (
     _argparse_formatter,
@@ -32,9 +34,10 @@ class ParserSpecification:
     helptext_from_nested_class_field_name: Dict[str, Optional[str]]
     subparsers_from_name: Dict[str, SubparsersSpecification]
     prefix: str
+    has_required_args: bool
 
     @staticmethod
-    def from_callable(
+    def from_callable_or_type(
         f: Callable[..., T],
         description: Optional[str],
         parent_classes: Set[Type],
@@ -43,8 +46,9 @@ class ParserSpecification:
             T, _fields.PropagatingMissingType, _fields.NonpropagatingMissingType
         ],
         prefix: str,
+        subcommand_prefix: str = "",
     ) -> ParserSpecification:
-        """Create a parser definition from a callable."""
+        """Create a parser definition from a callable or type."""
 
         # Resolve generic types.
         f, type_from_typevar = _resolver.resolve_generic_types(f)
@@ -68,6 +72,7 @@ class ParserSpecification:
         # cleaned up.
         parent_classes = parent_classes | {cast(Type, f)}
 
+        has_required_args = False
         args = []
         helptext_from_nested_class_field_name = {}
         subparsers_from_name = {}
@@ -92,7 +97,7 @@ class ParserSpecification:
                     f"Field {field.name} has an unbound TypeVar: {field.typ}."
                 )
 
-            if _markers.FIXED not in field.markers:
+            if _markers.Fixed not in field.markers:
                 # (1) Handle Unions over callables; these result in subparsers.
                 subparsers_attempt = SubparsersSpecification.from_field(
                     field,
@@ -101,9 +106,11 @@ class ParserSpecification:
                     prefix=_strings.make_field_name([prefix, field.name]),
                 )
                 if subparsers_attempt is not None:
+                    if subparsers_attempt.required:
+                        has_required_args = True
                     if (
                         not subparsers_attempt.required
-                        and _markers.AVOID_SUBCOMMANDS in field.markers
+                        and _markers.AvoidSubcommands in field.markers
                     ):
                         # Don't make a subparser.
                         field = dataclasses.replace(field, typ=type(field.default))
@@ -122,14 +129,17 @@ class ParserSpecification:
                             field.default,
                         ),
                     )
-                    nested_parser = ParserSpecification.from_callable(
+                    nested_parser = ParserSpecification.from_callable_or_type(
                         field.typ,
                         description=None,
                         parent_classes=parent_classes,
                         parent_type_from_typevar=type_from_typevar,
                         default_instance=field.default,
                         prefix=_strings.make_field_name([prefix, field.name]),
+                        subcommand_prefix=subcommand_prefix,
                     )
+                    if nested_parser.has_required_args:
+                        has_required_args = True
                     args.extend(nested_parser.args)
 
                     # Include nested subparsers.
@@ -155,13 +165,15 @@ class ParserSpecification:
                     continue
 
             # (3) Handle primitive or fixed types. These produce a single argument!
-            args.append(
-                _arguments.ArgumentDefinition(
-                    prefix=prefix,
-                    field=field,
-                    type_from_typevar=type_from_typevar,
-                )
+            arg = _arguments.ArgumentDefinition(
+                prefix=prefix,
+                subcommand_prefix=subcommand_prefix,
+                field=field,
+                type_from_typevar=type_from_typevar,
             )
+            args.append(arg)
+            if arg.lowered.required:
+                has_required_args = True
 
         # If a later subparser is required, all previous ones should be as well.
         subparsers_required = False
@@ -181,6 +193,7 @@ class ParserSpecification:
             helptext_from_nested_class_field_name=helptext_from_nested_class_field_name,
             subparsers_from_name=subparsers_from_name,
             prefix=prefix,
+            has_required_args=has_required_args,
         )
 
     def apply(self, parser: argparse.ArgumentParser) -> None:
@@ -299,13 +312,17 @@ class SubparsersSpecification:
                     ),
                 )
 
-            subparser = ParserSpecification.from_callable(
-                option,
+            subparser = ParserSpecification.from_callable_or_type(
+                # Recursively apply markers.
+                Annotated.__class_getitem__((option,) + tuple(field.markers))  # type: ignore
+                if len(field.markers) > 0
+                else option,
                 description=found_subcommand_configs[0].description,
                 parent_classes=parent_classes,
                 parent_type_from_typevar=type_from_typevar,
                 default_instance=found_subcommand_configs[0].default,
                 prefix=prefix,
+                subcommand_prefix=prefix,
             )
 
             # Apply prefix to helptext in nested classes in subparsers.
@@ -443,7 +460,7 @@ class SubparsersSpecification:
                 subparser = argparse_subparsers.add_parser(
                     name,
                     formatter_class=_argparse_formatter.DcargsArgparseHelpFormatter,
-                    help=subparser_def.description,
+                    help=rich.markup.escape(subparser_def.description),
                 )
                 subparser_def.apply(subparser)
 
